@@ -12,9 +12,20 @@ from PyFin.API.DateUtilities import advanceDate
 from PyFin.API.DateUtilities import adjustDateByCalendar
 from PyFin.API.DateUtilities import advanceDateByCalendar
 
+from PyFin.API.Analysis import MA
+from PyFin.API.Analysis import MAX
+from PyFin.API.Analysis import MIN
+from PyFin.API.Analysis import NPOSITIVE
+from PyFin.API.Analysis import MAPOSITIVE
+
 __all__ = ["datesList",
            "bizDatesList",
            "holDatesList",
            "advanceDate",
            "adjustDateByCalendar",
-           "advanceDateByCalendar"]
+           "advanceDateByCalendar",
+           "MA",
+           "MAX",
+           "MIN",
+           "NPOSITIVE",
+           "MAPOSITIVE"]
