@@ -1,11 +1,9 @@
-__author__ = 'cheng.li'
+# -*- coding: utf-8 -*-
+u"""
+Created on 2015-7-13
 
-__all__ = ["API",
-           "DateUtilities",
-           "Env",
-           "Math",
-           "PricingEngines",
-           "Risk"]
+@author: cheng.li
+"""
 
 from PyFin.tests import API
 from PyFin.tests import DateUtilities
@@ -13,3 +11,10 @@ from PyFin.tests import Env
 from PyFin.tests import Math
 from PyFin.tests import PricingEngines
 from PyFin.tests import Analysis
+
+__all__ = ["API",
+           "DateUtilities",
+           "Env",
+           "Math",
+           "PricingEngines",
+           "Risk"]
